@@ -1,8 +1,7 @@
 context("create")
 
 test_that("cpp_create_environment()", {
-  env_cb <- cpp_create_environment(letters, "toupper")
-  env <- env_cb$env
+  env <- cpp_create_environment(letters, "toupper")
   expect_equal(env$a, "A")
   expect_equal(env$x, "X")
   expect_null(env$X)
@@ -11,10 +10,8 @@ test_that("cpp_create_environment()", {
 })
 
 test_that("cpp_create_environment() with inheritance", {
-  env_cb <- cpp_create_environment(letters, "toupper")
-  env <- env_cb$env
-  env2_cb <- cpp_create_environment(LETTERS, "tolower", parent = env)
-  env2 <- env2_cb$env
+  env <- cpp_create_environment(letters, "toupper")
+  env2 <- cpp_create_environment(LETTERS, "tolower", parent = env)
   expect_equal(get("a", env2), "A")
   expect_equal(get("x", env2), "X")
   expect_null(env2$a)
